@@ -41,11 +41,14 @@ _DEFAULT_LOGGING_CONTEXT_FORMAT = ('%(asctime)s.%(msecs)03d %(process)d '
 def set_defaults(conf, backend=None, barbican_endpoint=None,
                  barbican_api_version=None, auth_endpoint=None,
                  retry_delay=None, number_of_retries=None, verify_ssl=None,
+                 verify_ssl_path=None,
                  api_class=None, vault_root_token_id=None,
                  vault_approle_role_id=None, vault_approle_secret_id=None,
                  vault_kv_mountpoint=None, vault_url=None,
                  vault_ssl_ca_crt_file=None, vault_use_ssl=None,
-                 barbican_endpoint_type=None):
+                 vault_namespace=None,
+                 barbican_endpoint_type=None,
+                 vault_kv_version=None):
     """Set defaults for configuration values.
 
     Overrides the default options values.
@@ -57,6 +60,7 @@ def set_defaults(conf, backend=None, barbican_endpoint=None,
     :param retry_delay: Use this attribute to set retry delay.
     :param number_of_retries: Use this attribute to set number of retries.
     :param verify_ssl: Use this to specify if ssl should be verified.
+    :param verify_ssl_path: Use this to specify the CA path.
     :param vault_root_token_id: Use this for the root token id for vault.
     :param vault_approle_role_id: Use this for the approle role_id for vault.
     :param vault_approle_secret_id: Use this for the approle secret_id
@@ -65,8 +69,10 @@ def set_defaults(conf, backend=None, barbican_endpoint=None,
     :param vault_url: Use this for the url for vault.
     :param vault_use_ssl: Use this to force vault driver to use ssl.
     :param vault_ssl_ca_crt_file: Use this for the CA file for vault.
+    :param vault_namespace: Namespace to use for all requests to Vault.
     :param barbican_endpoint_type: Use this to specify the type of URL.
     :                              Valid values are: public, internal or admin.
+    :param vault_kv_version: Use this for the kv version for vault.
     """
     conf.register_opts(key_manager.key_manager_opts, group='key_manager')
 
@@ -103,6 +109,9 @@ def set_defaults(conf, backend=None, barbican_endpoint=None,
         if verify_ssl is not None:
             conf.set_default('verify_ssl', verify_ssl,
                              group=bkm._BARBICAN_OPT_GROUP)
+        if verify_ssl_path is not None:
+            conf.set_default('verify_ssl_path', verify_ssl_path,
+                             group=bkm._BARBICAN_OPT_GROUP)
         if barbican_endpoint_type is not None:
             conf.set_default('barbican_endpoint_type', barbican_endpoint_type,
                              group=bkm._BARBICAN_OPT_GROUP)
@@ -129,6 +138,12 @@ def set_defaults(conf, backend=None, barbican_endpoint=None,
         if vault_use_ssl is not None:
             conf.set_default('use_ssl', vault_use_ssl,
                              group=vkm._VAULT_OPT_GROUP)
+        if vault_namespace is not None:
+            conf.set_default('namespace', vault_namespace,
+                             group=vkm._VAULT_OPT_GROUP)
+        if vault_kv_version is not None:
+            conf.set_default('kv_version', vault_kv_version,
+                             group=vkm._VAULT_OPT_GROUP)
 
 
 def enable_logging(conf=None, app_name='castellan'):
